@@ -1,3 +1,21 @@
+"""
+GillesPy2 is a modeling toolkit for biochemical simulation.
+Copyright (C) 2019-2021 GillesPy2 developers.
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""
+
 from gillespy2.core.jsonify import TranslationTable
 from gillespy2.core.reaction import *
 from gillespy2.core.raterule import RateRule
@@ -82,10 +100,6 @@ def export_StochSS(gillespy_model, filename=None, return_stochss_model=False):
 
 
 class Model(SortableObject, Jsonify):
-    # reserved names for model species/parameter names, volume, and operators.
-    reserved_names = ['vol']
-    special_characters = ['[', ']', '+', '-', '*', '/', '.', '^']
-
     """
     Representation of a well mixed biochemical model. Contains reactions,
     parameters, species.
@@ -94,25 +108,28 @@ class Model(SortableObject, Jsonify):
     :type name: str
     
     :param population: The type of model being described. A discrete stochastic model is a
-    population model (True), a deterministic model is a concentration model
-    (False). Automatic conversion from population to concentration models
-    may be used, by setting the volume parameter.
-    Attributes
+        population model (True), a deterministic model is a concentration model
+        (False). Automatic conversion from population to concentration models
+        may be used, by setting the volume parameter.
     :type population: bool
 
     :param volume: The volume of the system matters when converting to from population to
-    concentration form. This will also set a parameter "vol" for use in
-    custom (i.e. non-mass-action) propensity functions.  
+        concentration form. This will also set a parameter "vol" for use in
+        custom (i.e. non-mass-action) propensity functions.  
     :type volume: float   
     
     :param tspan: The timepoints at which the model should be simulated. If None, a
-    default timespan is added. May be set later, see Model.timespan
+        default timespan is added. May be set later, see Model.timespan
     :type tspan: numpy ndarray
     
     :param annotation: Option further description of model
     :type annotation: str
     """
 
+    # reserved names for model species/parameter names, volume, and operators.
+    reserved_names = ['vol']
+    special_characters = ['[', ']', '+', '-', '*', '/', '.', '^']
+
     def __init__(self, name="", population=True, volume=1.0, tspan=None, annotation="model"):
         """ Create an empty model. """
 
@@ -252,7 +269,8 @@ class Model(SortableObject, Jsonify):
         """
         Generate a dictionary mapping user chosen species names to simplified formats which will be used
         later on by GillesPySolvers evaluating reaction propensity functions.
-        :return: the dictionary mapping user species names to their internal GillesPy notation.
+
+        :returns: the dictionary mapping user species names to their internal GillesPy notation.
         """
         species_name_mapping = OrderedDict([])
         for i, name in enumerate(self.listOfSpecies.keys()):
@@ -297,8 +315,8 @@ class Model(SortableObject, Jsonify):
 
     def get_all_species(self):
         """
-        Returns a dict of all species in the model, of the form:
-        {name : species object}
+        :returns: A dict of all species in the model, of the form:
+            {name : species object}
         """
         return self.listOfSpecies
 
@@ -357,7 +375,8 @@ class Model(SortableObject, Jsonify):
         """
         Generate a dictionary mapping user chosen parameter names to simplified formats which will be used
         later on by GillesPySolvers evaluating reaction propensity functions.
-        :return: the dictionary mapping user parameter names to their internal GillesPy notation.
+
+        :returns: the dictionary mapping user parameter names to their internal GillesPy notation.
         """
         parameter_name_mapping = OrderedDict()
         parameter_name_mapping['vol'] = 'V'
@@ -380,8 +399,8 @@ class Model(SortableObject, Jsonify):
 
     def get_all_parameters(self):
         """
-        Returns a dict of all parameters in the model, of the form:
-        {name : parameter object}
+        :returns: A dict of all parameters in the model, of the form:
+            {name : parameter object}
         """
         return self.listOfParameters
 
@@ -424,7 +443,7 @@ class Model(SortableObject, Jsonify):
         :type p_name: str
 
         :param expression: String that may be executed in C, describing the value of the
-        parameter. May reference other parameters by name. (e.g. "k1*4")
+            parameter. May reference other parameters by name. (e.g. "k1*4")
         :type expression: str
         """
 
@@ -471,7 +490,7 @@ class Model(SortableObject, Jsonify):
         Adds a reaction, or list of reactions to the model.
 
         :param reactions: The reaction or list of reaction objects to be added to the model
-        object.
+            object.
         :type reactions: Reaction, or list of Reactions
         """
 
@@ -558,6 +577,7 @@ class Model(SortableObject, Jsonify):
     def add_event(self, event):
         """
         Adds an event, or list of events to the model.
+
         :param event: The event or list of event objects to be added to the model object.
         :type event: Event, or list of Events
         """
@@ -584,8 +604,9 @@ class Model(SortableObject, Jsonify):
     def add_function_definition(self, function_definitions):
         """
         Add FunctionDefinition or list of FunctionDefinitions
+
         :param function_definitions: The FunctionDefinition, or list of FunctionDefinitions to be added to the model
-        object.
+            object.
         :type function_definitions: FunctionDefinition or list of FunctionDefinitions.
         """
         if isinstance(function_definitions, list):
@@ -604,6 +625,7 @@ class Model(SortableObject, Jsonify):
     def add_assignment_rule(self, assignment_rules):
         """
         Add AssignmentRule or list of AssignmentRules to the model object.
+
         :param assignment_rules: The AssignmentRule or list of AssignmentRules to be added to the model object.
         :type assignment_rules: AssignmentRule or list of AssignmentRules
         """
@@ -640,8 +662,8 @@ class Model(SortableObject, Jsonify):
         Set the time span of simulation. StochKit does not support non-uniform
         timespans. 
 
-        :param time_span: Evenly-spaced list of times at which to sample the species
-        populations during the simulation. Best to use the form np.linspace(<start time>, <end time>, <number of time-points, inclusive>)
+        :param time_span: Evenly-spaced list of times at which to sample the species populations during the simulation. 
+            Best to use the form np.linspace(<start time>, <end time>, <number of time-points, inclusive>)
         :type time_span: numpy ndarray
         """
         
@@ -657,13 +679,13 @@ class Model(SortableObject, Jsonify):
     def get_reaction(self, rname):
         """
         :param rname: name of reaction to return
-        :return: Reaction object
+        :returns: Reaction object
         """
         return self.listOfReactions[rname]
 
     def get_all_reactions(self):
         """
-        :return: dict of all Reaction objects
+        :returns: dict of all Reaction objects
         """
         return self.listOfReactions
 
@@ -684,19 +706,20 @@ class Model(SortableObject, Jsonify):
     def get_event(self, ename):
         """
         :param ename: Name of Event to get
-        :return: Event object
+        :returns: Event object
         """
         return self.listOfEvents[ename]
 
     def get_all_events(self):
         """
-        :return: dict of all Event objects
+        :returns: dict of all Event objects
         """
         return self.listOfEvents
 
     def delete_event(self, ename):
         """
         Removes specified Event from model
+
         :param ename: Name of Event to be removed
         """
         self.listOfEvents.pop(ename)
@@ -712,13 +735,13 @@ class Model(SortableObject, Jsonify):
     def get_rate_rule(self, rname):
         """
         :param rname: Name of Rate Rule to get
-        :return: RateRule object
+        :returns: RateRule object
         """
         return self.listOfRateRules[rname]
 
     def get_all_rate_rules(self):
         """
-        :return: dict of all Rate Rule objects
+        :returns: dict of all Rate Rule objects
         """
         return self.listOfRateRules
 
@@ -740,19 +763,20 @@ class Model(SortableObject, Jsonify):
     def get_assignment_rule(self, aname):
         """
         :param aname: Name of Assignment Rule to get
-        :return: Assignment Rule object
+        :returns: Assignment Rule object
         """
         return self.listOfAssignmentRules[aname]
 
     def get_all_assignment_rules(self):
         """
-        :return: dict of models Assignment Rules
+        :returns: dict of models Assignment Rules
         """
         return self.listOfAssignmentRules
 
     def delete_assignment_rule(self, aname):
         """
         Removes an assignment rule from a model
+
         :param aname: Name of AssignmentRule object to be removed from model
         """
         self.listOfAssignmentRules.pop(aname)
@@ -768,19 +792,20 @@ class Model(SortableObject, Jsonify):
     def get_function_definition(self, fname):
         """
         :param fname: name of Function to get
-        :return: FunctionDefinition object
+        :returns: FunctionDefinition object
         """
         return self.listOfFunctionDefinitions[fname]
 
     def get_all_function_definitions(self):
         """
-        :return: Dict of models function definitions
+        :returns: Dict of models function definitions
         """
         return self.listOfFunctionDefinitions
 
     def delete_function_definition(self, fname):
         """
         Removes specified Function Definition from model
+
         :param fname: Name of Function Definition to be removed
         """
         self.listOfFunctionDefinitions.pop(fname)
@@ -795,9 +820,10 @@ class Model(SortableObject, Jsonify):
 
     def get_element(self, ename):
         """
-        get element specified by name
+        Get element specified by name.
+
         :param ename: name of element to search for
-        :return:value of element, or 'element not found'
+        :returns: value of element, or 'element not found'
         """
         if ename in self.listOfReactions:
             return self.get_reaction(ename)
@@ -820,10 +846,12 @@ class Model(SortableObject, Jsonify):
         """
         Finds best solver for the users simulation. Currently, AssignmentRules, RateRules, FunctionDefinitions,
         Events, and Species with a dynamic, or continuous population must use the TauHybridSolver.
+
         :param precompile: If True, and the model contains no AssignmentRules, RateRules, FunctionDefinitions, Events,
-        or Species with a dynamic or continuous population, it will choose SSACSolver
+            or Species with a dynamic or continuous population, it will choose SSACSolver
         :type precompile: bool
-        :return: gillespy2.gillespySolver
+
+        :returns: gillespy2.gillespySolver
         """
         from gillespy2.solvers.numpy import can_use_numpy
         hybrid_check = False
@@ -861,8 +889,9 @@ class Model(SortableObject, Jsonify):
         """
         If user has specified a particular algorithm, we return either the Python or C++ version of that algorithm
         """
-        from gillespy2.solvers.cpp import can_use_cpp
         from gillespy2.solvers.numpy import can_use_numpy
+        from gillespy2.solvers.cpp.build.build_engine import BuildEngine
+        can_use_cpp = not len(BuildEngine.get_missing_dependencies())
 
         if not can_use_cpp and can_use_numpy:
             raise ModelError("Please install C++ or Numpy to use GillesPy2 solvers.")
@@ -901,8 +930,7 @@ class Model(SortableObject, Jsonify):
         parameters to be set here.
 
         :param solver: The solver by which to simulate the model. This solver object may
-        be initialized separately to specify an algorithm. Optional,
-        defaults to ssa solver.
+            be initialized separately to specify an algorithm. Optional, defaults to ssa solver.
         :type solver: gillespy.GillesPySolver
 
         :param timeout: Allows a time_out value in seconds to be sent to a signal handler, restricting simulation run-time
@@ -914,20 +942,21 @@ class Model(SortableObject, Jsonify):
         :param solver_args: Solver-specific arguments to be passed to solver.run()
 
         :param cpp_support: INTERNAL USE ONLY, flag for whether or not a computer has the capability to compile a
-        C++ program.
+            C++ program.
         :type cpp_support: bool
 
-        :return  If show_labels is False, returns a numpy array of arrays of species population data. If show_labels is
-        True,returns a Results object that inherits UserList and contains one or more Trajectory objects that
-        inherit UserDict. Results object supports graphing and csv export.
-
         :param algorithm: Specify algorithm ('ODE', 'Tau-Leaping', or 'SSA') for GillesPy2 to automatically pick best solver using that algorithm.
         :type algorithm: str
 
+        :returns:  If show_labels is False, returns a numpy array of arrays of species population data. If show_labels is
+            True,returns a Results object that inherits UserList and contains one or more Trajectory objects that
+            inherit UserDict. Results object supports graphing and csv export.
+
         To pause a simulation and retrieve data before the simulation, keyboard interrupt the simulation by pressing
         control+c or pressing stop on a jupyter notebook. To resume a simulation, pass your previously ran results
         into the run method, and set t = to the time you wish the resuming simulation to end (run(resume=results, t=x)).
-        Pause/Resume is only supported for SINGLE TRAJECTORY simulations. T MUST BE SET OR UNEXPECTED BEHAVIOR MAY OCCUR.
+        
+        **Pause/Resume is only supported for SINGLE TRAJECTORY simulations. T MUST BE SET OR UNEXPECTED BEHAVIOR MAY OCCUR.**
         """
 
         if not show_labels:
@@ -993,21 +1022,26 @@ class StochMLDocument():
     @classmethod
     def from_model(cls, model):
         """
-        Creates an StochKit XML document from an exisiting Mdoel object.
+        Creates an StochKit XML document from an exisiting Model object.
         This method assumes that all the parameters in the model are already
         resolved to scalar floats (see Model.resolveParamters).
 
-        Note, this method is intended to be used interanally by the models
+        Note, this method is intended to be used internally by the models
         'serialization' function, which performs additional operations and
-        tests on the model prior to writing out the XML file. You should NOT \
-        do:
+        tests on the model prior to writing out the XML file. 
+        
+        You should NOT do:
 
-        document = StochMLDocument.fromModel(model)
-        print document.toString()
+        .. code-block:: python
 
-        You SHOULD do
+            document = StochMLDocument.fromModel(model)
+            print document.toString()
 
-        print model.serialize()
+        You SHOULD do:
+
+        .. code-block:: python
+
+            print model.serialize()
 
         """
 
