@@ -1,6 +1,28 @@
+"""
+GillesPy2 is a modeling toolkit for biochemical simulation.
+Copyright (C) 2019-2021 GillesPy2 developers.
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""
+
 import unittest
+from example_models import RobustModel
 from gillespy2.core import Model, Species, Reaction, Parameter
 from gillespy2.core.gillespyError import *
+from gillespy2.core.model import export_StochSS
+import tempfile
+import os
 import numpy as np
 
 
@@ -308,5 +330,30 @@ class TestModel(unittest.TestCase):
         with self.assertRaises(SpeciesError):
             sp2.set_initial_value(.5)
 
+    def test_robust_model(self):
+        try:
+            model = RobustModel()
+            model.run()
+        
+        except ModelError as e:
+            self.fail(f"Failed to instantiate the RobustModel: {e}")
+        
+        except SolverError as e:
+            self.fail(f"Failed to run the RobustModel: {e}")
+
+        except Exception as e:
+            self.fail(f"An unknown exception occured while testing the RobustModel: {e}")
+
+    def test_stochss_export(self):
+        model = RobustModel()
+        tempdir = tempfile.mkdtemp()
+        stochss_model_path = os.path.join(tempdir, "robust_model.mdl")
+        try:
+            export_StochSS(model, filename=stochss_model_path)
+            self.assertTrue(os.path.exists(stochss_model_path))
+        finally:
+            os.unlink(stochss_model_path)
+            os.rmdir(tempdir)
+
 if __name__ == '__main__':
     unittest.main()
